{ pkgs, lib, ... }:
let
  emailAddress = "felix.albrigtsen@ntnu.no";
in {
  imports = [
    ./../../home/base.nix
    ./../../home/alacritty.nix
  ];

  home.packages = with pkgs; [
    catimg
    chromium
    dante
    dig
    element-desktop
    gnome.gnome-keyring
    hunspellDicts.en_US
    hunspellDicts.nb_NO
    jq
    libreoffice
    maim
    mpv
    nixpkgs-2211.remmina
    oauth2ms
    openssl
    openstackclient
    pwgen
    rofi-rbw-x11
    unstable.tlclient
    traceroute
    w3m

    (python311.withPackages (ps: with ps; [
      numpy
      pycryptodome
      python-novaclient
      requests
    ]))
  ];

  programs = {
    aerc = {
      enable = true;
      package = pkgs.unstable.aerc;
    };
    alacritty.enable = true;
    firefox.enable = true;
    git.extraConfig.user.email = emailAddress;
    rbw = {
      enable = true;
      settings = {
        base_url = "https://bitwarden.it.ntnu.no";
        email = emailAddress;
        pinentry = pkgs.pinentry-gnome3;
      };
    };
    rofi = {
      enable = true;
      theme = "iggy";
    };
    zsh.shellAliases."rebuild" = "sudo nixos-rebuild switch --flake /config";

    neovim.plugins = with pkgs.vimPlugins; [ copilot-vim ];
  };

  xdg.mimeApps = {
    enable = true;

    defaultApplications = {
      "text/html" = "firefox.desktop";
      "x-scheme-handler/http" = "firefox.desktop";
      "x-scheme-handler/https" = "firefox.desktop";
      "x-scheme-handler/about" = "firefox.desktop";
      "x-scheme-handler/unknown" = "firefox.desktop";
    };
  };

  home.stateVersion = "24.05";
}
